@@ -1,7 +1,7 @@
 /* Test file for mpfr_atanh.
 
-Copyright 2001-2018 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 2001-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -178,7 +177,7 @@ main (int argc, char *argv[])
   test_generic (MPFR_PREC_MIN, 100, 25);
 
   data_check ("data/atanh", mpfr_atanh, "mpfr_atanh");
-  bad_cases (mpfr_atanh, mpfr_tanh, "mpfr_atanh", 256, -128, 9,
+  bad_cases (mpfr_atanh, mpfr_tanh, "mpfr_atanh", 256, -128, 8,
              4, 128, 800, 100);
 
   tests_end_mpfr ();
