@@ -1,7 +1,7 @@
 /* Test file for mpfr_exp.
 
-Copyright 1999, 2001-2020 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 1999, 2001-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -271,8 +270,8 @@ check_special (void)
 
   /* Check overflow. Corner case of mpfr_exp_2 */
   mpfr_set_prec (x, 64);
-  mpfr_set_emax (MPFR_EMAX_DEFAULT);
-  mpfr_set_emin (MPFR_EMIN_DEFAULT);
+  set_emax (MPFR_EMAX_DEFAULT);
+  set_emin (MPFR_EMIN_DEFAULT);
   mpfr_set_str (x,
     "0.1011000101110010000101111111010100001100000001110001100111001101E30",
                 2, MPFR_RNDN);
