@@ -1,7 +1,7 @@
 /* Test file for mpfr_fms.
 
-Copyright 2001-2018 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 2001-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -570,11 +569,11 @@ main (int argc, char *argv[])
             mpfr_urandomb (y, RANDS);
             mpfr_urandomb (z, RANDS);
 
-            if (randlimb () % 2)
+            if (RAND_BOOL ())
               mpfr_neg (x, x, MPFR_RNDN);
-            if (randlimb () % 2)
+            if (RAND_BOOL ())
               mpfr_neg (y, y, MPFR_RNDN);
-            if (randlimb () % 2)
+            if (RAND_BOOL ())
               mpfr_neg (z, z, MPFR_RNDN);
 
             rnd = RND_RAND_NO_RNDF ();
