@@ -1,7 +1,7 @@
-/* mpfr_tgamma -- test file for gamma function
+/* Test file for gamma function
 
-Copyright 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
-Contributed by the AriC and Caramel projects, INRIA.
+Copyright 2001-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,12 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
-
-#include <stdio.h>
-#include <stdlib.h>
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -109,11 +105,11 @@ special (void)
   mpfr_set_str (x, CHECK_Y1, 10, MPFR_RNDN);
   if (mpfr_cmp (y, x))
     {
-      printf ("mpfr_lngamma("CHECK_X1") is wrong:\n"
+      printf ("mpfr_lngamma(" CHECK_X1 ") is wrong:\n"
               "expected ");
-      mpfr_print_binary (x); putchar ('\n');
+      mpfr_dump (x);
       printf ("got      ");
-      mpfr_print_binary (y); putchar ('\n');
+      mpfr_dump (y);
       exit (1);
     }
 
@@ -124,11 +120,11 @@ special (void)
   mpfr_set_str (x, CHECK_Y2, 10, MPFR_RNDN);
   if (mpfr_cmp (y, x))
     {
-      printf ("mpfr_lngamma("CHECK_X2") is wrong:\n"
+      printf ("mpfr_lngamma(" CHECK_X2 ") is wrong:\n"
               "expected ");
-      mpfr_print_binary (x); putchar ('\n');
+      mpfr_dump (x);
       printf ("got      ");
-      mpfr_print_binary (y); putchar ('\n');
+      mpfr_dump (y);
       exit (1);
     }
 
@@ -153,8 +149,8 @@ special (void)
   if (mpfr_cmp (x, y))
     {
       printf ("Error in mpfr_gamma (120)\n");
-      printf ("Expected "); mpfr_print_binary (y); puts ("");
-      printf ("Got      "); mpfr_print_binary (x); puts ("");
+      printf ("Expected "); mpfr_dump (y);
+      printf ("Got      "); mpfr_dump (x);
       exit (1);
     }
 
@@ -192,6 +188,18 @@ special (void)
       exit (1);
     }
 
+  mpfr_set_prec (x, 2);
+  mpfr_set_prec (y, 2);
+  mpfr_set_ui (x, 2, MPFR_RNDN);
+  mpfr_clear_inexflag ();
+  mpfr_gamma (y, x, MPFR_RNDN);
+  if (mpfr_inexflag_p ())
+    {
+      printf ("Wrong inexact flag for gamma(2)\n");
+      printf ("expected 0, got 1\n");
+      exit (1);
+    }
+
   mpfr_clear (x);
   mpfr_clear (y);
 }
@@ -225,7 +233,7 @@ special_overflow (void)
   mpfr_set_prec (y, 29);
   mpfr_set_str (x, "-200000000.5", 10, MPFR_RNDN); /* exact */
   mpfr_gamma (y, x, MPFR_RNDN);
-  if (!(mpfr_zero_p (y) && MPFR_SIGN (y) < 0))
+  if (!(mpfr_zero_p (y) && MPFR_IS_NEG (y)))
     {
       printf ("Error for gamma(-200000000.5)\n");
       printf ("expected -0");
@@ -238,7 +246,7 @@ special_overflow (void)
   mpfr_set_prec (y, 53);
   mpfr_set_str (x, "-200000000.1", 10, MPFR_RNDN);
   mpfr_gamma (y, x, MPFR_RNDN);
-  if (!(mpfr_zero_p (y) && MPFR_SIGN (y) < 0))
+  if (!(mpfr_zero_p (y) && MPFR_IS_NEG (y)))
     {
       printf ("Error for gamma(-200000000.1), prec=53\n");
       printf ("expected -0");
@@ -317,11 +325,11 @@ special_overflow (void)
   mpfr_set_prec (y, 38);
   mpfr_set_str (x, "-2993155353253689176481146537402947624254601559176535", 10,
                 MPFR_RNDN);
-  mpfr_div_2exp (x, x, 170, MPFR_RNDN);
+  mpfr_div_2ui (x, x, 170, MPFR_RNDN);
   mpfr_gamma (y, x, MPFR_RNDN);
   mpfr_set_prec (x, 38);
   mpfr_set_str (x, "201948391737", 10, MPFR_RNDN);
-  mpfr_mul_2exp (x, x, 92, MPFR_RNDN);
+  mpfr_mul_2ui (x, x, 92, MPFR_RNDN);
   if (mpfr_cmp (x, y))
     {
       printf ("Error for gamma (test 5)\n");
@@ -352,7 +360,7 @@ special_overflow (void)
   mpfr_set_prec (y, 71);
   mpfr_set_str (x, "-200000000.1", 10, MPFR_RNDN);
   mpfr_gamma (y, x, MPFR_RNDN);
-  if (!(mpfr_zero_p (y) && MPFR_SIGN (y) < 0))
+  if (!(mpfr_zero_p (y) && MPFR_IS_NEG (y)))
     {
       printf ("Error for gamma (test 8)\n");
       printf ("expected "); mpfr_dump (x);
@@ -360,7 +368,7 @@ special_overflow (void)
       exit (1);
     }
 
-  set_emax (1073741823);
+  set_emax (1073741821);
   mpfr_set_prec (x, 29);
   mpfr_set_prec (y, 29);
   mpfr_set_str (x, "423786866", 10, MPFR_RNDN);
@@ -381,7 +389,7 @@ special_overflow (void)
       exit (1);
     }
 
-  mpfr_set_emax (1024);
+  set_emax (1024);
   mpfr_set_prec (x, 53);
   mpfr_set_prec (y, 53);
   mpfr_set_str_binary (x, "101010110100110011111010000110001000111100000110101E-43");
@@ -447,7 +455,7 @@ test20071231 (void)
   mpfr_exp_t emin;
 
   emin = mpfr_get_emin ();
-  mpfr_set_emin (-1000000);
+  set_emin (-1000000);
 
   mpfr_init2 (x, 21);
   mpfr_set_str (x, "-1000001.5", 10, MPFR_RNDN);
@@ -455,7 +463,7 @@ test20071231 (void)
   MPFR_ASSERTN(MPFR_IS_ZERO(x) && MPFR_IS_POS(x) && inex < 0);
   mpfr_clear (x);
 
-  mpfr_set_emin (emin);
+  set_emin (emin);
 
   mpfr_init2 (x, 53);
   mpfr_set_str (x, "-1000000001.5", 10, MPFR_RNDN);
@@ -496,7 +504,7 @@ test20100709 (void)
   /* Similar test for 64-bit machines (also valid with a 32-bit exponent,
      but will not trigger the bug). */
   emin = mpfr_get_emin ();
-  mpfr_set_emin (MPFR_EMIN_MIN);
+  set_emin (MPFR_EMIN_MIN);
   mpfr_init2 (x, 100);
   mpfr_init2 (y, 32);
   mpfr_init2 (z, 32);
@@ -514,7 +522,7 @@ test20100709 (void)
   mpfr_clear (x);
   mpfr_clear (y);
   mpfr_clear (z);
-  mpfr_set_emin (emin);
+  set_emin (emin);
 }
 
 /* bug found by Giridhar Tammana */
@@ -527,9 +535,9 @@ test20120426 (void)
 
   mpfr_init2 (xa, 53);
   mpfr_init2 (xb, 53);
-  mpfr_set_d (xb, -168.5, MPFR_RNDN);
+  mpfr_set_si_2exp (xb, -337, -1, MPFR_RNDN);
   emin = mpfr_get_emin ();
-  mpfr_set_emin (-1073);
+  set_emin (-1073);
   i = mpfr_gamma (xa, xb, MPFR_RNDN);
   i = mpfr_subnormalize (xa, i, MPFR_RNDN); /* new ternary value */
   mpfr_set_str (xb, "-9.5737343987585366746184749943e-304", 10, MPFR_RNDN);
@@ -537,12 +545,12 @@ test20120426 (void)
     {
       printf ("Error in test20120426, i=%d\n", i);
       printf ("expected ");
-      mpfr_print_binary (xb); putchar ('\n');
+      mpfr_dump (xb);
       printf ("got      ");
-      mpfr_print_binary (xa); putchar ('\n');
+      mpfr_dump (xa);
       exit (1);
     }
-  mpfr_set_emin (emin);
+  set_emin (emin);
   mpfr_clear (xa);
   mpfr_clear (xb);
 }
@@ -566,20 +574,20 @@ exprange (void)
   inex1 = mpfr_gamma (y, x, MPFR_RNDN);
   flags1 = __gmpfr_flags;
   MPFR_ASSERTN (mpfr_inexflag_p ());
-  mpfr_set_emin (0);
+  set_emin (0);
   mpfr_clear_flags ();
   inex2 = mpfr_gamma (z, x, MPFR_RNDN);
   flags2 = __gmpfr_flags;
   MPFR_ASSERTN (mpfr_inexflag_p ());
-  mpfr_set_emin (emin);
+  set_emin (emin);
   if (inex1 != inex2 || flags1 != flags2 || ! mpfr_equal_p (y, z))
     {
       printf ("Error in exprange (test1)\n");
       printf ("x = ");
       mpfr_dump (x);
-      printf ("Expected inex1 = %d, flags1 = %u, ", SIGN (inex1), flags1);
+      printf ("Expected inex1 = %d, flags1 = %u, ", VSIGN (inex1), flags1);
       mpfr_dump (y);
-      printf ("Got      inex2 = %d, flags2 = %u, ", SIGN (inex2), flags2);
+      printf ("Got      inex2 = %d, flags2 = %u, ", VSIGN (inex2), flags2);
       mpfr_dump (z);
       exit (1);
     }
@@ -589,25 +597,25 @@ exprange (void)
   inex1 = mpfr_gamma (y, x, MPFR_RNDD);
   flags1 = __gmpfr_flags;
   MPFR_ASSERTN (mpfr_inexflag_p ());
-  mpfr_set_emax (45);
+  set_emax (45);
   mpfr_clear_flags ();
   inex2 = mpfr_gamma (z, x, MPFR_RNDD);
   flags2 = __gmpfr_flags;
   MPFR_ASSERTN (mpfr_inexflag_p ());
-  mpfr_set_emax (emax);
+  set_emax (emax);
   if (inex1 != inex2 || flags1 != flags2 || ! mpfr_equal_p (y, z))
     {
       printf ("Error in exprange (test2)\n");
       printf ("x = ");
       mpfr_dump (x);
-      printf ("Expected inex1 = %d, flags1 = %u, ", SIGN (inex1), flags1);
+      printf ("Expected inex1 = %d, flags1 = %u, ", VSIGN (inex1), flags1);
       mpfr_dump (y);
-      printf ("Got      inex2 = %d, flags2 = %u, ", SIGN (inex2), flags2);
+      printf ("Got      inex2 = %d, flags2 = %u, ", VSIGN (inex2), flags2);
       mpfr_dump (z);
       exit (1);
     }
 
-  mpfr_set_emax (44);
+  set_emax (44);
   mpfr_clear_flags ();
   inex1 = mpfr_check_range (y, inex1, MPFR_RNDD);
   flags1 = __gmpfr_flags;
@@ -616,15 +624,15 @@ exprange (void)
   inex2 = mpfr_gamma (z, x, MPFR_RNDD);
   flags2 = __gmpfr_flags;
   MPFR_ASSERTN (mpfr_inexflag_p ());
-  mpfr_set_emax (emax);
+  set_emax (emax);
   if (inex1 != inex2 || flags1 != flags2 || ! mpfr_equal_p (y, z))
     {
       printf ("Error in exprange (test3)\n");
       printf ("x = ");
       mpfr_dump (x);
-      printf ("Expected inex1 = %d, flags1 = %u, ", SIGN (inex1), flags1);
+      printf ("Expected inex1 = %d, flags1 = %u, ", VSIGN (inex1), flags1);
       mpfr_dump (y);
-      printf ("Got      inex2 = %d, flags2 = %u, ", SIGN (inex2), flags2);
+      printf ("Got      inex2 = %d, flags2 = %u, ", VSIGN (inex2), flags2);
       mpfr_dump (z);
       exit (1);
     }
@@ -634,27 +642,27 @@ exprange (void)
   inex1 = mpfr_gamma (y, x, MPFR_RNDD);
   flags1 = __gmpfr_flags;
   MPFR_ASSERTN (mpfr_inexflag_p ());
-  mpfr_set_emax (60);
+  set_emax (60);
   mpfr_clear_flags ();
   inex2 = mpfr_gamma (z, x, MPFR_RNDD);
   flags2 = __gmpfr_flags;
   MPFR_ASSERTN (mpfr_inexflag_p ());
-  mpfr_set_emax (emax);
+  set_emax (emax);
   if (inex1 != inex2 || flags1 != flags2 || ! mpfr_equal_p (y, z))
     {
       printf ("Error in exprange (test4)\n");
       printf ("x = ");
       mpfr_dump (x);
-      printf ("Expected inex1 = %d, flags1 = %u, ", SIGN (inex1), flags1);
+      printf ("Expected inex1 = %d, flags1 = %u, ", VSIGN (inex1), flags1);
       mpfr_dump (y);
-      printf ("Got      inex2 = %d, flags2 = %u, ", SIGN (inex2), flags2);
+      printf ("Got      inex2 = %d, flags2 = %u, ", VSIGN (inex2), flags2);
       mpfr_dump (z);
       exit (1);
     }
 
   MPFR_ASSERTN (MPFR_EMIN_MIN == - MPFR_EMAX_MAX);
-  mpfr_set_emin (MPFR_EMIN_MIN);
-  mpfr_set_emax (MPFR_EMAX_MAX);
+  set_emin (MPFR_EMIN_MIN);
+  set_emax (MPFR_EMAX_MAX);
   mpfr_set_ui (x, 0, MPFR_RNDN);
   mpfr_nextabove (x);  /* x = 2^(emin - 1) */
   mpfr_set_inf (y, 1);
@@ -670,9 +678,9 @@ exprange (void)
       printf ("Error in exprange (test5)\n");
       printf ("x = ");
       mpfr_dump (x);
-      printf ("Expected inex1 = %d, flags1 = %u, ", SIGN (inex1), flags1);
+      printf ("Expected inex1 = %d, flags1 = %u, ", VSIGN (inex1), flags1);
       mpfr_dump (y);
-      printf ("Got      inex2 = %d, flags2 = %u, ", SIGN (inex2), flags2);
+      printf ("Got      inex2 = %d, flags2 = %u, ", VSIGN (inex2), flags2);
       mpfr_dump (z);
       exit (1);
     }
@@ -686,9 +694,9 @@ exprange (void)
       printf ("Error in exprange (test6)\n");
       printf ("x = ");
       mpfr_dump (x);
-      printf ("Expected inex1 = %d, flags1 = %u, ", SIGN (inex1), flags1);
+      printf ("Expected inex1 = %d, flags1 = %u, ", VSIGN (inex1), flags1);
       mpfr_dump (y);
-      printf ("Got      inex2 = %d, flags2 = %u, ", SIGN (inex2), flags2);
+      printf ("Got      inex2 = %d, flags2 = %u, ", VSIGN (inex2), flags2);
       mpfr_dump (z);
       exit (1);
     }
@@ -704,9 +712,9 @@ exprange (void)
       printf ("Error in exprange (test7)\n");
       printf ("x = ");
       mpfr_dump (x);
-      printf ("Expected inex1 = %d, flags1 = %u, ", SIGN (inex1), flags1);
+      printf ("Expected inex1 = %d, flags1 = %u, ", VSIGN (inex1), flags1);
       mpfr_dump (y);
-      printf ("Got      inex2 = %d, flags2 = %u, ", SIGN (inex2), flags2);
+      printf ("Got      inex2 = %d, flags2 = %u, ", VSIGN (inex2), flags2);
       mpfr_dump (z);
       exit (1);
     }
@@ -724,9 +732,9 @@ exprange (void)
       printf ("Error in exprange (test8)\n");
       printf ("x = ");
       mpfr_dump (x);
-      printf ("Expected inex1 = %d, flags1 = %u, ", SIGN (inex1), flags1);
+      printf ("Expected inex1 = %d, flags1 = %u, ", VSIGN (inex1), flags1);
       mpfr_dump (y);
-      printf ("Got      inex2 = %d, flags2 = %u, ", SIGN (inex2), flags2);
+      printf ("Got      inex2 = %d, flags2 = %u, ", VSIGN (inex2), flags2);
       mpfr_dump (z);
       exit (1);
     }
@@ -740,9 +748,9 @@ exprange (void)
       printf ("Error in exprange (test9)\n");
       printf ("x = ");
       mpfr_dump (x);
-      printf ("Expected inex1 = %d, flags1 = %u, ", SIGN (inex1), flags1);
+      printf ("Expected inex1 = %d, flags1 = %u, ", VSIGN (inex1), flags1);
       mpfr_dump (y);
-      printf ("Got      inex2 = %d, flags2 = %u, ", SIGN (inex2), flags2);
+      printf ("Got      inex2 = %d, flags2 = %u, ", VSIGN (inex2), flags2);
       mpfr_dump (z);
       exit (1);
     }
@@ -759,14 +767,14 @@ exprange (void)
       printf ("Error in exprange (test10)\n");
       printf ("x = ");
       mpfr_dump (x);
-      printf ("Expected inex1 = %d, flags1 = %u, ", SIGN (inex1), flags1);
+      printf ("Expected inex1 = %d, flags1 = %u, ", VSIGN (inex1), flags1);
       mpfr_dump (y);
-      printf ("Got      inex2 = %d, flags2 = %u, ", SIGN (inex2), flags2);
+      printf ("Got      inex2 = %d, flags2 = %u, ", VSIGN (inex2), flags2);
       mpfr_dump (z);
       exit (1);
     }
-  mpfr_set_emin (emin);
-  mpfr_set_emax (emax);
+  set_emin (emin);
+  set_emax (emax);
 
   mpfr_clears (x, y, z, (mpfr_ptr) 0);
 }
@@ -788,7 +796,7 @@ tiny_aux (int stop, mpfr_exp_t e)
   spm = 1;
   for (s = 0; s < 2; s++)
     {
-      RND_LOOP(r)
+      RND_LOOP_NO_RNDF (r)
         {
           mpfr_rnd_t rr = (mpfr_rnd_t) r;
           mpfr_exp_t exponent, emax;
@@ -803,7 +811,7 @@ tiny_aux (int stop, mpfr_exp_t e)
 
               if (emax > MPFR_EMAX_MAX)
                 break;
-              mpfr_set_emax (emax);
+              set_emax (emax);
 
               mpfr_clear_flags ();
               inex = mpfr_gamma (y, x, rr);
@@ -827,12 +835,12 @@ tiny_aux (int stop, mpfr_exp_t e)
                 {
                   printf ("Error in tiny for s = %d, r = %s, emax = %"
                           MPFR_EXP_FSPEC "d%s\n  on ",
-                          s, mpfr_print_rnd_mode (rr), emax,
+                          s, mpfr_print_rnd_mode (rr), (mpfr_eexp_t) emax,
                           exponent > emax ? " (overflow)" : "");
                   mpfr_dump (x);
                   printf ("  expected inex = %2d, ", expected_inex);
                   mpfr_dump (z);
-                  printf ("  got      inex = %2d, ", SIGN (inex));
+                  printf ("  got      inex = %2d, ", VSIGN (inex));
                   mpfr_dump (y);
                   printf ("  expected flags = %u, got %u\n",
                           expected_flags, flags);
@@ -847,7 +855,7 @@ tiny_aux (int stop, mpfr_exp_t e)
     }
 
   mpfr_clears (x, y, z, (mpfr_ptr) 0);
-  mpfr_set_emax (saved_emax);
+  set_emax (saved_emax);
   return err;
 }
 
@@ -868,9 +876,9 @@ tiny (int stop)
 
   if (emin != MPFR_EMIN_MIN)
     {
-      mpfr_set_emin (MPFR_EMIN_MIN);
+      set_emin (MPFR_EMIN_MIN);
       err |= tiny_aux (stop, MPFR_EMIN_MIN);
-      mpfr_set_emin (emin);
+      set_emin (emin);
     }
 
   if (err)
@@ -881,7 +889,7 @@ tiny (int stop)
    computing with a working precision p2. Assume that x is not an
    integer <= 2. */
 static void
-exp_lgamma (mpfr_t x, mpfr_prec_t p1, mpfr_prec_t p2)
+exp_lgamma (mpfr_ptr x, mpfr_prec_t p1, mpfr_prec_t p2)
 {
   mpfr_t yd, yu, zd, zu;
   int inexd, inexu, sign;
@@ -1046,16 +1054,71 @@ exp_lgamma_tests (void)
   set_emax (emax);
 }
 
+/* Bug reported by Frithjof Blomquist on May 19, 2020.
+   For the record, this bug was present since r8981
+   (in mpfr_bernoulli_internal, den was wrongly reset to 1 in case
+   of failure in Ziv's loop). The bug only occurred up from r8986
+   where the initial precision was reduced, but was potentially
+   present in any case of failure of Ziv's loop. */
+static void
+bug20200519 (void)
+{
+  mpfr_prec_t prec = 25093;
+  mpfr_t x, y, z, d;
+  double dd;
+  size_t min_memory_limit, old_memory_limit;
+
+  old_memory_limit = tests_memory_limit;
+  min_memory_limit = 24000000;
+  if (tests_memory_limit > 0 && tests_memory_limit < min_memory_limit)
+    tests_memory_limit = min_memory_limit;
+
+  mpfr_init2 (x, prec);
+  mpfr_init2 (y, prec);
+  mpfr_init2 (z, prec + 100);
+  mpfr_init2 (d, 24);
+  mpfr_set_d (x, 2.5, MPFR_RNDN);
+  mpfr_gamma (y, x, MPFR_RNDN);
+  mpfr_gamma (z, x, MPFR_RNDN);
+  mpfr_sub (d, y, z, MPFR_RNDN);
+  mpfr_mul_2si (d, d, prec - mpfr_get_exp (y), MPFR_RNDN);
+  dd = mpfr_get_d (d, MPFR_RNDN);
+  if (dd < -0.5 || 0.5 < dd)
+    {
+      printf ("Error in bug20200519: dd=%f\n", dd);
+      exit (1);
+    }
+  mpfr_clear (x);
+  mpfr_clear (y);
+  mpfr_clear (z);
+  mpfr_clear (d);
+
+  tests_memory_limit = old_memory_limit;
+}
+
 int
 main (int argc, char *argv[])
 {
   tests_start_mpfr ();
 
+  if (argc == 3) /* tgamma x prec: print gamma(x) to prec bits */
+    {
+      mpfr_prec_t p = atoi (argv[2]);
+      mpfr_t x;
+      mpfr_init2 (x, p);
+      mpfr_set_str (x, argv[1], 10, MPFR_RNDN);
+      mpfr_gamma (x, x, MPFR_RNDN);
+      mpfr_out_str (stdout, 10, 0, x, MPFR_RNDN);
+      printf ("\n");
+      mpfr_clear (x);
+      return 0;
+    }
+
   special ();
   special_overflow ();
   exprange ();
   tiny (argc == 1);
-  test_generic (2, 100, 2);
+  test_generic (MPFR_PREC_MIN, 100, 2);
   gamma_integer ();
   test20071231 ();
   test20100709 ();
@@ -1064,6 +1127,11 @@ main (int argc, char *argv[])
 
   data_check ("data/gamma", mpfr_gamma, "mpfr_gamma");
 
+  /* this test takes about one minute */
+  if (getenv ("MPFR_CHECK_EXPENSIVE") != NULL &&
+      getenv ("MPFR_CHECK_LARGEMEM") != NULL)
+    bug20200519 ();
+
   tests_end_mpfr ();
   return 0;
 }
