@@ -1,7 +1,7 @@
 /* Test file for mpfr_mul.
 
-Copyright 1999, 2001-2019 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 1999, 2001-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -334,10 +333,10 @@ check_max (void)
   MPFR_ASSERTN(mpfr_cmp (zz, yy) == 0);
   set_emin (emin);
 
-  /* coverage test for mulders.c, case n > 8448 (MUL_FFT_THRESHOLD default) */
-  mpfr_set_prec (xx, (8448 + 1) * GMP_NUMB_BITS);
-  mpfr_set_prec (yy, (8448 + 1) * GMP_NUMB_BITS);
-  mpfr_set_prec (zz, (8448 + 1) * GMP_NUMB_BITS);
+  /* coverage test for mulders.c, case n > MUL_FFT_THRESHOLD */
+  mpfr_set_prec (xx, (MUL_FFT_THRESHOLD + 1) * GMP_NUMB_BITS);
+  mpfr_set_prec (yy, (MUL_FFT_THRESHOLD + 1) * GMP_NUMB_BITS);
+  mpfr_set_prec (zz, (MUL_FFT_THRESHOLD + 1) * GMP_NUMB_BITS);
   mpfr_set_ui (xx, 1, MPFR_RNDN);
   mpfr_nextbelow (xx);
   mpfr_set_ui (yy, 1, MPFR_RNDN);
@@ -582,6 +581,7 @@ check_regression (void)
   mpfr_set_str (y, "-1.921fb54442d18469898cc51701b839a252049c1114cf98e804177d"
                 "4c76273644a29410f31c6809bbdf2a33679a748636600",
                 16, MPFR_RNDN);
+  /* the following call to mpfr_mul with identical arguments is intentional */
   i = mpfr_mul (x, y, y, MPFR_RNDU);
   if (mpfr_cmp_str (x, "2.77a79937c8bbcb495b89b36602306b1c2159a8ff834288a19a08"
     "84094f1cda3dc426da61174c4544a173de83c2500f8bfea2e0569e3698",
@@ -746,7 +746,7 @@ test_underflow (mpfr_prec_t pmax)
           printf ("c="); mpfr_dump (c);
           printf ("a="); mpfr_dump (a);
           mpfr_set_prec (a, mpfr_get_prec (b) + mpfr_get_prec (c));
-          mpfr_mul_2exp (b, b, 1, MPFR_RNDN);
+          mpfr_mul_2ui (b, b, 1, MPFR_RNDN);
           inex = mpfr_mul (a, b, c, MPFR_RNDN);
           MPFR_ASSERTN (inex == 0);
           printf ("Exact 2*a="); mpfr_dump (a);
@@ -789,7 +789,7 @@ test_underflow (mpfr_prec_t pmax)
           printf ("c="); mpfr_dump (c);
           printf ("a="); mpfr_dump (a);
           mpfr_set_prec (a, mpfr_get_prec (b) + mpfr_get_prec (c));
-          mpfr_mul_2exp (b, b, 1, MPFR_RNDN);
+          mpfr_mul_2ui (b, b, 1, MPFR_RNDN);
           inex = mpfr_mul (a, b, c, MPFR_RNDN);
           MPFR_ASSERTN (inex == 0);
           printf ("Exact 2*a="); mpfr_dump (a);
@@ -1032,8 +1032,9 @@ small_prec (void)
         inex2 = mpfr_mul (z2, x, y, rnd);
         flags2 = __gmpfr_flags;
         if (!(mpfr_equal_p (z1, z2) &&
-              SAME_SIGN (inex1, inex2) &&
-              flags1 == flags2))
+              SAME_SIGN (inex1, inex2)
+              && flags1 == flags2
+              ))
           {
             printf ("Error in small_prec on i = %d, j = %d\n", i, j);
             printf ("r = 0x%x, xq = %d, yq = %d, zq = %d, rnd = %s\n",
@@ -1070,7 +1071,7 @@ test_underflow2 (void)
   mpfr_exp_t emin;
 
   emin = mpfr_get_emin ();
-  mpfr_set_emin (0);
+  set_emin (0);
 
   mpfr_init2 (x, 24);
   mpfr_init2 (y, 24);
@@ -1099,7 +1100,7 @@ test_underflow2 (void)
   mpfr_clear (x);
   mpfr_clear (z);
 
-  mpfr_set_emin (emin);
+  set_emin (emin);
 }
 
 static void
@@ -1265,12 +1266,42 @@ coverage (mpfr_prec_t pmax)
     }
 }
 
+/* check special underflow case for precision = 64 */
+static void
+coverage2 (void)
+{
+  mpfr_t a, b, c;
+  int inex;
+  mpfr_exp_t emin;
+
+  emin = mpfr_get_emin (); /* save emin */
+  set_emin (0);
+
+  mpfr_init2 (a, 64);
+  mpfr_init2 (b, 64);
+  mpfr_init2 (c, 64);
+
+  mpfr_set_str_binary (b, "1111110110100001011100100000100000110110001100100010011010011001E-64"); /* 18276014142440744601/2^64 */
+  mpfr_set_str_binary (c, "1000000100110010000111000100010010010001000100101010111101010100E-64"); /* 9309534460545511252/2^64 */
+  /* since 1/2-2^-66 < b0*c0 < 1/2, b0*c0 should be rounded to 1/2 */
+  inex = mpfr_mul (a, b, c, MPFR_RNDN);
+  MPFR_ASSERTN(mpfr_cmp_ui_2exp (a, 1, -1) == 0);
+  MPFR_ASSERTN(inex > 0);
+
+  mpfr_clear (a);
+  mpfr_clear (b);
+  mpfr_clear (c);
+
+  set_emin (emin); /* restore emin */
+}
+
 int
 main (int argc, char *argv[])
 {
   tests_start_mpfr ();
 
   coverage (1024);
+  coverage2 ();
   testall_rndf (9);
   check_nans ();
   check_exact ();
