@@ -1,8 +1,8 @@
 /* Test file for internal debugging-out functions:
    mpfr_print_rnd_mode, mpfr_dump, mpfr_print_mant_binary.
 
-Copyright 2004-2020 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 2004-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -17,9 +17,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -107,13 +106,13 @@ main (void)
   MPFR_MANT(x)[MPFR_LAST_LIMB(x)] >>= 1;
   MPFR_MANT(x)[0] |= 1;
   e = mpfr_get_emin ();
-  mpfr_set_emin (33);
+  set_emin (33);
   mpfr_dump (x);
-  mpfr_set_emin (e);
+  set_emin (e);
   e = mpfr_get_emax ();
-  mpfr_set_emax (31);
+  set_emax (31);
   mpfr_dump (x);
-  mpfr_set_emax (e);
+  set_emax (e);
   mpfr_clear (x);
   fclose (stdout);
 
