@@ -1,7 +1,7 @@
 /* Test file for mpfr_pow_z -- power function x^z with z a MPZ
 
-Copyright 2005-2020 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 2005-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -331,7 +330,7 @@ bug20080904 (void)
   mpfr_init2 (answer, 70);
 
   emin_default = mpfr_get_emin ();
-  mpfr_set_emin (MPFR_EMIN_MIN);
+  set_emin (MPFR_EMIN_MIN);
 
   mpz_set_str (exp, "-4eb92f8c7b7bf81e", 16);
   mpfr_set_str_binary (a, "1.110000101110100110100011111000011110111101000011111001111001010011100");
@@ -352,7 +351,7 @@ bug20080904 (void)
       exit (1);
     }
 
-  mpfr_set_emin (emin_default);
+  set_emin (emin_default);
 
   mpz_clear (exp);
   mpfr_clear (a);
