@@ -1,7 +1,7 @@
 /* Test file for mpfr_set_ld and mpfr_get_ld.
 
-Copyright 2002-2020 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 2002-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include <float.h>
 
@@ -239,7 +238,8 @@ check_set_get (long double d)
               printf ("  d ~= %.36Le (output may be wrong!)\n", d);
               printf ("  e ~= %.36Le (output may be wrong!)\n", e);
               ld_trace ("  d", d);
-              printf ("  x = "); mpfr_out_str (NULL, 16, 0, x, MPFR_RNDN);
+              printf ("  x = ");
+              mpfr_out_str (stdout, 16, 0, x, MPFR_RNDN);
               printf ("\n");
               ld_trace ("  e", e);
               printf ("  d = ");
@@ -286,16 +286,16 @@ test_small (void)
                  mpfr_erangeflag_p ()))
     {
       printf ("Error with x = ");
-      mpfr_out_str (NULL, 10, 21, x, MPFR_RNDN);
+      mpfr_out_str (stdout, 10, 21, x, MPFR_RNDN);
       printf (" = ");
-      mpfr_out_str (NULL, 16, 0, x, MPFR_RNDN);
+      mpfr_out_str (stdout, 16, 0, x, MPFR_RNDN);
       printf ("\n        -> d = %.33Le", d);
       printf ("\n        -> y = ");
-      mpfr_out_str (NULL, 10, 21, y, MPFR_RNDN);
+      mpfr_out_str (stdout, 10, 21, y, MPFR_RNDN);
       printf (" = ");
-      mpfr_out_str (NULL, 16, 0, y, MPFR_RNDN);
+      mpfr_out_str (stdout, 16, 0, y, MPFR_RNDN);
       printf ("\n        -> |x-y| = ");
-      mpfr_out_str (NULL, 16, 0, z, MPFR_RNDN);
+      mpfr_out_str (stdout, 16, 0, z, MPFR_RNDN);
       printf ("\n");
       exit (1);
     }
@@ -360,7 +360,7 @@ check_subnormal (void)
       e = mpfr_get_ld (x, MPFR_RNDN);
       if (e != d)
         {
-          printf ("Error for mpfr_get_ld o mpfr_set_ld\n");
+          printf ("Error in check_subnormal for mpfr_get_ld o mpfr_set_ld\n");
           printf ("d=%.30Le\n", d);
           printf ("x="); mpfr_dump (x);
           printf ("e=%.30Le\n", e);
