@@ -1,7 +1,7 @@
 /* Test file for mpfr_sin_cos.
 
-Copyright 2000-2004, 2006-2018 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 2000-2004, 2006-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -576,7 +575,7 @@ consistency (void)
         {
           int j = i / MPFR_RND_MAX;
           if (j & 1)
-            mpfr_set_emin (MPFR_EMIN_MIN);
+            set_emin (MPFR_EMIN_MIN);
           mpfr_set_si (x, (j & 2) ? 1 : -1, MPFR_RNDN);
           mpfr_set_exp (x, mpfr_get_emin ());
           rnd = (mpfr_rnd_t) (i % MPFR_RND_MAX);
@@ -584,13 +583,13 @@ consistency (void)
             goto end;
           flags_before = 0;
           if (j & 4)
-            mpfr_set_emax (-17);
+            set_emax (-17);
         }
       else
         {
           tests_default_random (x, 256, -5, 50, 0);
           rnd = RND_RAND_NO_RNDF ();
-          flags_before = (randlimb () & 1) ?
+          flags_before = RAND_BOOL () ?
             (unsigned int) (MPFR_FLAGS_ALL ^ MPFR_FLAGS_ERANGE) :
             (unsigned int) 0;
         }
@@ -631,8 +630,8 @@ consistency (void)
         }
     end:
       mpfr_clears (x, s1, s2, c1, c2, (mpfr_ptr) 0);
-      mpfr_set_emin (emin);
-      mpfr_set_emax (emax);
+      set_emin (emin);
+      set_emax (emax);
     }
 }
 
