@@ -1,7 +1,7 @@
 /* Test file for mpfr_sqrt.
 
-Copyright 1999, 2001-2019 Free Software Foundation, Inc.
-Contributed by the AriC and Caramba projects, INRIA.
+Copyright 1999, 2001-2025 Free Software Foundation, Inc.
+Contributed by the Pascaline and Caramba projects, INRIA.
 
 This file is part of the GNU MPFR Library.
 
@@ -16,9 +16,8 @@ or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
-https://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
-51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.
+If not, see <https://www.gnu.org/licenses/>. */
 
 #include "mpfr-test.h"
 
@@ -175,7 +174,7 @@ check_float (void)
   check24("281474876047360.0", MPFR_RNDD, "1.6777212e7");
   check24("91214552498176.0", MPFR_RNDD, "9.550631e6");
 
-  /* check that rounding away is just rounding toward plus infinity */
+  /* check that rounding away is just rounding toward positive infinity */
   check24("91214552498176.0", MPFR_RNDA, "9.550632e6");
 }
 
@@ -289,7 +288,7 @@ special (void)
 
   mpfr_set_prec (x, 53);
   mpfr_set_str (x, "8093416094703476.0", 10, MPFR_RNDN);
-  mpfr_div_2exp (x, x, 1075, MPFR_RNDN);
+  mpfr_div_2ui (x, x, 1075, MPFR_RNDN);
   test_sqrt (x, x, MPFR_RNDN);
   mpfr_set_str (z, "1e55596835b5ef@-141", 16, MPFR_RNDN);
   if (mpfr_cmp (x, z))
@@ -341,7 +340,7 @@ special (void)
   mpfr_set_prec (z, GMP_NUMB_BITS - 1);
   mpfr_set_prec (y, GMP_NUMB_BITS - 1);
   mpfr_set_ui (y, 1, MPFR_RNDN);
-  mpfr_mul_2exp (y, y, GMP_NUMB_BITS - 1, MPFR_RNDN);
+  mpfr_mul_2ui (y, y, GMP_NUMB_BITS - 1, MPFR_RNDN);
   mpfr_nextabove (y);
   for (p = 2 * GMP_NUMB_BITS - 1; p <= 1000; p++)
     {
@@ -350,7 +349,7 @@ special (void)
       mpfr_set_exp (x, GMP_NUMB_BITS);
       mpfr_add_ui (x, x, 1, MPFR_RNDN);
       /* now x = 2^(GMP_NUMB_BITS - 1) + 1 (GMP_NUMB_BITS bits) */
-      inexact = mpfr_mul (x, x, x, MPFR_RNDN);
+      inexact = mpfr_sqr (x, x, MPFR_RNDN);
       MPFR_ASSERTN (inexact == 0); /* exact */
       inexact = test_sqrt (z, x, MPFR_RNDN);
       /* even rule: z should be 2^(GMP_NUMB_BITS - 1) */
@@ -429,7 +428,7 @@ check_inexact (mpfr_prec_t p)
   mpfr_urandomb (x, RANDS);
   rnd = RND_RAND_NO_RNDF ();
   inexact = test_sqrt (y, x, rnd);
-  if (mpfr_mul (z, y, y, rnd)) /* exact since prec(z) = 2*prec(y) */
+  if (mpfr_sqr (z, y, rnd)) /* exact since prec(z) = 2*prec(y) */
     {
       printf ("Error: multiplication should be exact\n");
       exit (1);
@@ -661,20 +660,28 @@ test_sqrt1n (void)
   mpfr_t r, u;
   int inex;
 
+  MPFR_ASSERTD(GMP_NUMB_BITS >= 8); /* so that 15^2 is exactly representable */
+
   mpfr_init2 (r, GMP_NUMB_BITS);
   mpfr_init2 (u, GMP_NUMB_BITS);
 
-  inex = mpfr_set_ui_2exp (u, 17 * 17, 2 * GMP_NUMB_BITS - 10, MPFR_RNDN);
+  inex = mpfr_set_ui_2exp (u, 9 * 9, 2 * GMP_NUMB_BITS - 10, MPFR_RNDN);
   MPFR_ASSERTN(inex == 0);
   inex = mpfr_sqrt (r, u, MPFR_RNDN);
   MPFR_ASSERTN(inex == 0);
-  MPFR_ASSERTN(mpfr_cmp_ui_2exp (r, 17, GMP_NUMB_BITS - 5) == 0);
+  MPFR_ASSERTN(mpfr_cmp_ui_2exp (r, 9, GMP_NUMB_BITS - 5) == 0);
+
+  inex = mpfr_set_ui_2exp (u, 15 * 15, 2 * GMP_NUMB_BITS - 10, MPFR_RNDN);
+  MPFR_ASSERTN(inex == 0);
+  inex = mpfr_sqrt (r, u, MPFR_RNDN);
+  MPFR_ASSERTN(inex == 0);
+  MPFR_ASSERTN(mpfr_cmp_ui_2exp (r, 15, GMP_NUMB_BITS - 5) == 0);
 
   inex = mpfr_set_ui_2exp (u, 1, GMP_NUMB_BITS - 2, MPFR_RNDN);
   MPFR_ASSERTN(inex == 0);
   inex = mpfr_add_ui (u, u, 1, MPFR_RNDN);
   MPFR_ASSERTN(inex == 0);
-  inex = mpfr_mul_2exp (u, u, GMP_NUMB_BITS, MPFR_RNDN);
+  inex = mpfr_mul_2ui (u, u, GMP_NUMB_BITS, MPFR_RNDN);
   MPFR_ASSERTN(inex == 0);
   /* u = 2^(2*GMP_NUMB_BITS-2) + 2^GMP_NUMB_BITS, thus
      u = r^2 + 2^GMP_NUMB_BITS with r = 2^(GMP_NUMB_BITS-1).
@@ -703,10 +710,10 @@ check_overflow (void)
       mpfr_init2 (r, p);
       mpfr_init2 (u, p);
 
-      mpfr_set_emax (-1);
+      set_emax (-1);
       mpfr_set_ui_2exp (u, 1, mpfr_get_emax () - 1, MPFR_RNDN);
       mpfr_nextbelow (u);
-      mpfr_mul_2exp (u, u, 1, MPFR_RNDN);
+      mpfr_mul_2ui (u, u, 1, MPFR_RNDN);
       /* now u = (1 - 2^(-p))*2^emax is the largest number < +Inf,
          it square root is near 0.707 and has exponent 0 > emax */
       /* for RNDN, the result should be +Inf */
@@ -722,10 +729,10 @@ check_overflow (void)
       MPFR_ASSERTN(inex < 0);
       MPFR_ASSERTN(mpfr_equal_p (r, u));
 
-      mpfr_set_emax (0);
+      set_emax (0);
       mpfr_set_ui_2exp (u, 1, mpfr_get_emax () - 1, MPFR_RNDN);
       mpfr_nextbelow (u);
-      mpfr_mul_2exp (u, u, 1, MPFR_RNDN);
+      mpfr_mul_2ui (u, u, 1, MPFR_RNDN);
       /* u = 1-2^(-p), its square root is > u, and should thus give +Inf when
          rounding away */
       inex = mpfr_sqrt (r, u, MPFR_RNDA);
@@ -735,7 +742,7 @@ check_overflow (void)
       mpfr_clear (r);
       mpfr_clear (u);
     }
-  mpfr_set_emax (emax);
+  set_emax (emax);
 }
 
 static void
@@ -752,7 +759,7 @@ check_underflow (void)
       mpfr_init2 (r, p);
       mpfr_init2 (u, p);
 
-      mpfr_set_emin (2);
+      set_emin (2);
       mpfr_set_ui_2exp (u, 1, mpfr_get_emin () - 1, MPFR_RNDN); /* u = 2 */
       /* for RNDN, since sqrt(2) is closer from 2 than 0, the result is 2 */
       mpfr_clear_flags ();
@@ -838,7 +845,7 @@ check_underflow (void)
       MPFR_ASSERTN(mpfr_cmp_ui_2exp (r, 1, mpfr_get_emin () - 1) == 0);
       MPFR_ASSERTN(mpfr_underflow_p ());
 
-      mpfr_set_emin (3);
+      set_emin (3);
       mpfr_set_ui_2exp (u, 1, mpfr_get_emin () - 1, MPFR_RNDN); /* u = 4 */
       /* sqrt(u) = 2 = 0.5^2^(emin-1) should be rounded to +0 */
       mpfr_clear_flags ();
@@ -857,7 +864,7 @@ check_underflow (void)
       MPFR_ASSERTN(mpfr_cmp_ui (r, 4) == 0);
       MPFR_ASSERTN(mpfr_underflow_p ());
 
-      mpfr_set_emin (4);
+      set_emin (4);
       mpfr_set_ui_2exp (u, 1, mpfr_get_emin () - 1, MPFR_RNDN); /* u = 8 */
       /* sqrt(u) should be rounded to +0 */
       mpfr_clear_flags ();
@@ -869,7 +876,7 @@ check_underflow (void)
       mpfr_clear (r);
       mpfr_clear (u);
     }
-  mpfr_set_emin (emin);
+  set_emin (emin);
 }
 
 static void
@@ -894,7 +901,7 @@ coverage (void)
       mpfr_nextabove (w); /* w = nextabove(v) */
       mpfr_set (t, v, MPFR_RNDN);
       mpfr_nextabove (t);
-      mpfr_mul (u, t, t, MPFR_RNDN);
+      mpfr_sqr (u, t, MPFR_RNDN);
       inex = mpfr_sqrt (r, u, MPFR_RNDN);
       if (mpfr_min_prec (v) < p) /* v is even */
         {
@@ -1045,13 +1052,13 @@ main (void)
   check4 ("72154663483843080704304789585920.0", MPFR_RNDD,
           "1.e2d9a51977e6d@13");
 
-  /* check that rounding away is just rounding toward plus infinity */
+  /* check that rounding away is just rounding toward positive infinity */
   check4 ("72154663483843080704304789585920.0", MPFR_RNDA,
           "1.e2d9a51977e6e@13");
 
   test_generic (MPFR_PREC_MIN, 300, 15);
   data_check ("data/sqrt", mpfr_sqrt, "mpfr_sqrt");
-  bad_cases (mpfr_sqrt, mpfr_sqr, "mpfr_sqrt", 8, -256, 255, 4, 128, 800, 50);
+  bad_cases (mpfr_sqrt, mpfr_sqr, "mpfr_sqrt", 0, -256, 255, 4, 128, 80, 50);
 
   bug20160120 ();
   bug20160908 ();
